@@ -25,7 +25,8 @@ from pytensor.graph import node_rewriter
 from pytensor.graph.basic import Apply, Variable
 from pytensor.graph.op import Op
 from pytensor.raise_op import Assert
-from pytensor.sparse.basic import DenseFromSparse, sp_sum
+from pytensor.sparse.basic import DenseFromSparse
+from pytensor.sparse.math import sp_sum
 from pytensor.tensor import (
     TensorConstant,
     TensorVariable,
@@ -35,7 +36,7 @@ from pytensor.tensor import (
 )
 from pytensor.tensor.elemwise import DimShuffle
 from pytensor.tensor.exceptions import NotScalarConstantError
-from pytensor.tensor.linalg import cholesky, det, eigh, solve_triangular, trace
+from pytensor.tensor.linalg import det, eigh, solve_triangular, trace
 from pytensor.tensor.linalg import inv as matrix_inverse
 from pytensor.tensor.random import chisquare
 from pytensor.tensor.random.basic import MvNormalRV, dirichlet, multinomial, multivariate_normal
@@ -123,13 +124,6 @@ def simplex_cont_transform(op, rv):
     return transforms.simplex
 
 
-# Step methods and advi do not catch LinAlgErrors at the
-# moment. We work around that by using a cholesky op
-# that returns a nan as first entry instead of raising
-# an error.
-nan_lower_cholesky = partial(cholesky, lower=True, on_error="nan")
-
-
 def quaddist_matrix(cov=None, chol=None, tau=None, lower=True, *args, **kwargs):
     if len([i for i in [tau, cov, chol] if i is not None]) != 1:
         raise ValueError("Incompatible parameterization. Specify exactly one of tau, cov, or chol.")
@@ -149,11 +143,11 @@ def quaddist_matrix(cov=None, chol=None, tau=None, lower=True, *args, **kwargs):
             raise ValueError("chol must be at least two dimensional.")
 
         if not lower:
-            chol = pt.swapaxes(chol, -1, -2)
+            chol = chol.mT
 
         # tag as lower triangular to enable pytensor rewrites of chol(l.l') -> l
         chol.tag.lower_triangular = True
-        cov = pt.matmul(chol, pt.swapaxes(chol, -1, -2))
+        cov = chol @ chol.mT
 
     return cov
 
@@ -175,13 +169,9 @@ def quaddist_chol(value, mu, cov):
     else:
         onedim = False
 
-    chol_cov = nan_lower_cholesky(cov)
+    chol_cov = pt.linalg.cholesky(cov, lower=True)
     logdet, posdef = _logdet_from_cholesky(chol_cov)
 
-    # solve_triangular will raise if there are nans
-    # (which happens if the cholesky fails)
-    chol_cov = pt.switch(posdef[..., None, None], chol_cov, 1)
-
     delta = value - mu
     delta_trans = solve_lower(chol_cov, delta, b_ndim=1)
     quaddist = (delta_trans**2).sum(axis=-1)
@@ -346,7 +336,7 @@ def precision_mv_normal_logp(op: PrecisionMvNormalRV, value, rng, size, mean, ta
 
     delta = value - mean
     quadratic_form = delta.T @ tau @ delta
-    logdet, posdef = _logdet_from_cholesky(nan_lower_cholesky(tau))
+    logdet, posdef = _logdet_from_cholesky(pt.linalg.cholesky(tau, lower=True))
     logp = -0.5 * (k * pt.log(2 * np.pi) + quadratic_form) + logdet
 
     return check_parameters(
@@ -1390,7 +1380,7 @@ class LKJCholeskyCov:
 
     Examples
     --------
-    .. code:: python
+    .. code-block:: python
 
         with pm.Model() as model:
             # Note that we access the distribution for the standard
@@ -1656,7 +1646,7 @@ class LKJCorr:
 
     The LKJ distribution is a prior distribution for correlation matrices.
     If eta = 1 this corresponds to the uniform distribution over correlation
-    matrices. For eta -> oo the LKJ prior approaches the identity matrix.
+    matrices. For eta :math:`\to \infty` the LKJ prior approaches the identity matrix.
 
     ========  ==============================================
     Support   Upper triangular matrix with values in [-1, 1]
@@ -1682,28 +1672,25 @@ class LKJCorr:
 
     Examples
     --------
-    .. code:: python
+    .. code-block:: python
 
         with pm.Model() as model:
-
             # Define the vector of fixed standard deviations
-            sds = 3*np.ones(10)
+            sds = 3 * np.ones(10)
 
-            corr = pm.LKJCorr(
-                'corr', eta=4, n=10, return_matrix=True
-            )
+            corr = pm.LKJCorr("corr", eta=4, n=10, return_matrix=True)
 
             # Define a new MvNormal with the given correlation matrix
-            vals = sds*pm.MvNormal('vals', mu=np.zeros(10), cov=corr, shape=10)
+            vals = sds * pm.MvNormal("vals", mu=np.zeros(10), cov=corr, shape=10)
 
             # Or transform an uncorrelated normal distribution:
-            vals_raw = pm.Normal('vals_raw', shape=10)
+            vals_raw = pm.Normal("vals_raw", shape=10)
             chol = pt.linalg.cholesky(corr)
-            vals = sds*pt.dot(chol,vals_raw)
+            vals = sds * pt.dot(chol, vals_raw)
 
             # The matrix is internally still sampled as a upper triangular vector
             # If you want access to it in matrix form in the trace, add
-            pm.Deterministic('corr_mat', corr)
+            pm.Deterministic("corr_mat", corr)
 
 
     References
@@ -1797,7 +1784,7 @@ class MatrixNormal(Continuous):
     Define a matrixvariate normal variable for given row and column covariance
     matrices.
 
-    .. code:: python
+    .. code-block:: python
 
         import pymc as pm
         import numpy as np
@@ -1820,16 +1807,20 @@ class MatrixNormal(Continuous):
     constant, both the covariance and scaling could be learned as follows
     (see the docstring of `LKJCholeskyCov` for more information about this)
 
-    .. code:: python
+    .. code-block:: python
 
         # Setup data
-        true_colcov = np.array([[1.0, 0.5, 0.1],
-                                [0.5, 1.0, 0.2],
-                                [0.1, 0.2, 1.0]])
+        true_colcov = np.array(
+            [
+                [1.0, 0.5, 0.1],
+                [0.5, 1.0, 0.2],
+                [0.1, 0.2, 1.0],
+            ]
+        )
         m = 3
         n = true_colcov.shape[0]
         true_scale = 3
-        true_rowcov = np.diag([true_scale**(2*i) for i in range(m)])
+        true_rowcov = np.diag([true_scale ** (2 * i) for i in range(m)])
         mu = np.zeros((m, n))
         true_kron = np.kron(true_rowcov, true_colcov)
         data = np.random.multivariate_normal(mu.flatten(), true_kron)
@@ -1838,13 +1829,12 @@ class MatrixNormal(Continuous):
         with pm.Model() as model:
             # Setup right cholesky matrix
             sd_dist = pm.HalfCauchy.dist(beta=2.5, shape=3)
-            colchol,_,_ = pm.LKJCholeskyCov('colchol', n=3, eta=2,sd_dist=sd_dist)
+            colchol, _, _ = pm.LKJCholeskyCov("colchol", n=3, eta=2, sd_dist=sd_dist)
             # Setup left covariance matrix
-            scale = pm.LogNormal('scale', mu=np.log(true_scale), sigma=0.5)
-            rowcov = pt.diag([scale**(2*i) for i in range(m)])
+            scale = pm.LogNormal("scale", mu=np.log(true_scale), sigma=0.5)
+            rowcov = pt.diag([scale ** (2 * i) for i in range(m)])
 
-            vals = pm.MatrixNormal('vals', mu=mu, colchol=colchol, rowcov=rowcov,
-                                observed=data)
+            vals = pm.MatrixNormal("vals", mu=mu, colchol=colchol, rowcov=rowcov, observed=data)
     """
 
     rv_op = matrixnormal
@@ -1860,8 +1850,6 @@ class MatrixNormal(Continuous):
         *args,
         **kwargs,
     ):
-        lower_cholesky = partial(cholesky, lower=True, on_error="raise")
-
         # Among-row matrices
         if len([i for i in [rowcov, rowchol] if i is not None]) != 1:
             raise ValueError(
@@ -1870,7 +1858,7 @@ class MatrixNormal(Continuous):
         if rowcov is not None:
             if rowcov.ndim != 2:
                 raise ValueError("rowcov must be two dimensional.")
-            rowchol_cov = lower_cholesky(rowcov)
+            rowchol_cov = pt.linalg.cholesky(rowcov, lower=True)
         else:
             if rowchol.ndim != 2:
                 raise ValueError("rowchol must be two dimensional.")
@@ -1885,7 +1873,7 @@ class MatrixNormal(Continuous):
             colcov = pt.as_tensor_variable(colcov)
             if colcov.ndim != 2:
                 raise ValueError("colcov must be two dimensional.")
-            colchol_cov = lower_cholesky(colcov)
+            colchol_cov = pt.linalg.cholesky(colcov, lower=True)
         else:
             if colchol.ndim != 2:
                 raise ValueError("colchol must be two dimensional.")
@@ -2010,15 +1998,15 @@ class KroneckerNormal(Continuous):
     Define a multivariate normal variable with a covariance
     :math:`K = K_1 \otimes K_2`
 
-    .. code:: python
+    .. code-block:: python
 
-        K1 = np.array([[1., 0.5], [0.5, 2]])
-        K2 = np.array([[1., 0.4, 0.2], [0.4, 2, 0.3], [0.2, 0.3, 1]])
+        K1 = np.array([[1.0, 0.5], [0.5, 2]])
+        K2 = np.array([[1.0, 0.4, 0.2], [0.4, 2, 0.3], [0.2, 0.3, 1]])
         covs = [K1, K2]
         N = 6
         mu = np.zeros(N)
         with pm.Model() as model:
-            vals = pm.KroneckerNormal('vals', mu=mu, covs=covs, shape=N)
+            vals = pm.KroneckerNormal("vals", mu=mu, covs=covs, shape=N)
 
     Efficiency gains are made by cholesky decomposing :math:`K_1` and
     :math:`K_2` individually rather than the larger :math:`K` matrix. Although
@@ -2026,14 +2014,14 @@ class KroneckerNormal(Continuous):
     number of submatrices can be combined in this way. Choleskys and
     eigendecompositions can be provided instead
 
-    .. code:: python
+    .. code-block:: python
 
         chols = [np.linalg.cholesky(Ki) for Ki in covs]
         evds = [np.linalg.eigh(Ki) for Ki in covs]
         with pm.Model() as model:
-            vals2 = pm.KroneckerNormal('vals2', mu=mu, chols=chols, shape=N)
+            vals2 = pm.KroneckerNormal("vals2", mu=mu, chols=chols, shape=N)
             # or
-            vals3 = pm.KroneckerNormal('vals3', mu=mu, evds=evds, shape=N)
+            vals3 = pm.KroneckerNormal("vals3", mu=mu, evds=evds, shape=N)
 
     neither of which will be converted. Diagonal noise can also be added to
     the covariance matrix, :math:`K = K_1 \otimes K_2 + \sigma^2 I_N`.
@@ -2042,13 +2030,13 @@ class KroneckerNormal(Continuous):
     utilizing eigendecompositons of the submatrices behind the scenes [1].
     Thus,
 
-    .. code:: python
+    .. code-block:: python
 
         sigma = 0.1
         with pm.Model() as noise_model:
-            vals = pm.KroneckerNormal('vals', mu=mu, covs=covs, sigma=sigma, shape=N)
-            vals2 = pm.KroneckerNormal('vals2', mu=mu, chols=chols, sigma=sigma, shape=N)
-            vals3 = pm.KroneckerNormal('vals3', mu=mu, evds=evds, sigma=sigma, shape=N)
+            vals = pm.KroneckerNormal("vals", mu=mu, covs=covs, sigma=sigma, shape=N)
+            vals2 = pm.KroneckerNormal("vals2", mu=mu, chols=chols, sigma=sigma, shape=N)
+            vals3 = pm.KroneckerNormal("vals3", mu=mu, evds=evds, sigma=sigma, shape=N)
 
     are identical, with `covs` and `chols` each converted to
     eigendecompositions.
@@ -2263,10 +2251,12 @@ class CAR(Continuous):
     def dist(cls, mu, W, alpha, tau, *args, **kwargs):
         # This variable has an expensive validation check, that we want to constant-fold if possible
         # So it's passed as an explicit input
-        W = pytensor.sparse.as_sparse_or_tensor_variable(W)
+        from pytensor.sparse import as_sparse_or_tensor_variable, sign
+
+        W = as_sparse_or_tensor_variable(W)
         if isinstance(W.type, pytensor.sparse.SparseTensorType):
-            abs_diff = pytensor.sparse.basic.mul(pytensor.sparse.sign(W - W.T), W - W.T)
-            W_is_valid = pt.isclose(pytensor.sparse.sp_sum(abs_diff), 0)
+            abs_diff = sign(W - W.T) * (W - W.T)
+            W_is_valid = pt.isclose(abs_diff.sum(), 0)
         else:
             W_is_valid = pt.allclose(W, W.T)
 
@@ -2307,7 +2297,7 @@ class CAR(Continuous):
         if W.owner and isinstance(W.owner.op, DenseFromSparse):
             W = W.owner.inputs[0]
 
-        sparse = isinstance(W, pytensor.sparse.SparseVariable)
+        sparse = isinstance(W, pytensor.sparse.variable.SparseVariable)
         if sparse:
             D = sp_sum(W, axis=0)
             Dinv_sqrt = pt.diag(1 / pt.sqrt(D))
@@ -2373,15 +2363,15 @@ class ICAR(Continuous):
     .. math::
         f(\phi| W,\sigma) =
           -\frac{1}{2\sigma^{2}} \sum_{i\sim j} (\phi_{i} - \phi_{j})^2 -
-          \frac{1}{2}*\frac{\sum_{i}{\phi_{i}}}{0.001N}^{2} - \ln{\sqrt{2\\pi}} -
+          \frac{1}{2}*\frac{\sum_{i}{\phi_{i}}}{0.001N}^{2} - \ln{\sqrt{2\pi}} -
           \ln{0.001N}
 
-    The first term represents the spatial covariance component. Each $\\phi_{i}$ is penalized
-    based on the square distance from each of its neighbors. The notation $i\\sim j$
-    indicates a sum over all the neighbors of $\\phi_{i}$. The last three terms are the
+    The first term represents the spatial covariance component. Each :math:`\phi_{i}` is penalized
+    based on the square distance from each of its neighbors. The notation :math:`i \sim j`
+    indicates a sum over all the neighbors of :math:`\phi_{i}`. The last three terms are the
     Normal log density function where the mean is zero and the standard deviation is
-    $N * 0.001$ (where N is the length of the vector $\\phi$). This component imposes
-    a zero-sum constraint by finding the sum of the vector $\\phi$ and penalizing based
+    N * 0.001 (where N is the length of the vector :math:`\phi`). This component imposes
+    a zero-sum constraint by finding the sum of the vector :math:`\phi` and penalizing based
     on its distance from zero.
 
     Parameters
@@ -2664,6 +2654,7 @@ class StickBreakingWeights(SimplexContinuous):
 class ZeroSumNormalRV(SymbolicRandomVariable):
     """ZeroSumNormal random variable."""
 
+    name = "ZeroSumNormal"
     _print_name = ("ZeroSumNormal", "\\operatorname{ZeroSumNormal}")
 
     @classmethod
@@ -2687,12 +2678,12 @@ class ZeroSumNormalRV(SymbolicRandomVariable):
             zerosum_rv -= zerosum_rv.mean(axis=-axis - 1, keepdims=True)
 
         support_str = ",".join([f"d{i}" for i in range(n_zerosum_axes)])
-        extended_signature = f"[rng],(),(s),[size]->[rng],({support_str})"
-        return ZeroSumNormalRV(
-            inputs=[rng, sigma, support_shape, size],
+        extended_signature = f"[rng],[size],(),(s)->[rng],({support_str})"
+        return cls(
+            inputs=[rng, size, sigma, support_shape],
             outputs=[next_rng, zerosum_rv],
             extended_signature=extended_signature,
-        )(rng, sigma, support_shape, size)
+        )(rng, size, sigma, support_shape)
 
 
 class ZeroSumNormal(Distribution):
@@ -2705,9 +2696,9 @@ class ZeroSumNormal(Distribution):
     .. math::
 
         \begin{align*}
-            ZSN(\sigma) = N \Big( 0, \sigma^2 (I - \tfrac{1}{n}J) \Big) \\
+            ZSN(\sigma) = N \Big( 0, \sigma^2 (I_K - \tfrac{1}{K}J_K) \Big) \\
             \text{where} \ ~ J_{ij} = 1 \ ~ \text{and} \\
-            n = \text{nbr of zero-sum axes}
+            K = \text{size (length) of the constrained axis}
         \end{align*}
 
     Parameters
@@ -2828,7 +2819,7 @@ def zerosum_default_transform(op, rv):
 
 
 @_logprob.register(ZeroSumNormalRV)
-def zerosumnormal_logp(op, values, rng, sigma, support_shape, size, **kwargs):
+def zerosumnormal_logp(op, values, rng, size, sigma, support_shape, **kwargs):
     (value,) = values
     shape = value.shape
     n_zerosum_axes = op.ndim_supp
